@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2020 Inria                                           *)
+(*  Copyright © 2012-2021 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -21,7 +21,7 @@
 
 open Js_of_ocaml
 
-let belenios = Js.Unsafe.variable "belenios"
+let belenios = Js.Unsafe.pure_js_expr "belenios"
 
 let debug x = Firebug.console##log (Js.string x)
 
@@ -133,7 +133,6 @@ let pbkdf2_generic toBits ~iterations ~salt x =
   let derived = Sjcl.sjcl##.misc##pbkdf2 (Js.string x) salt iterations 256 in
   hex_fromBits derived
 
-let pbkdf2_hex = pbkdf2_generic hex_toBits
 let pbkdf2_utf8 = pbkdf2_generic utf8String_toBits
 
 let aes_hex ~key ~data =
@@ -159,11 +158,10 @@ let decrypt ~key ~iv ~ciphertext =
   let plaintext = Sjcl.ccm##decrypt prf ciphertext iv in
   utf8String_fromBits plaintext
 
-type rng = unit -> unit
+type rng = unit
 
-(* PRNG is initialized in random.js *)
-let secure_rng () = ()
-let pseudo_rng _ () = ()
+let secure_rng = ()
+let pseudo_rng _ = ()
 
 let string_of_hex hex n =
   String.init n (fun i ->
@@ -171,8 +169,7 @@ let string_of_hex hex n =
     char_of_int c
   )
 
-let random_string rng n =
-  let () = rng () in
+let random_string () n =
   let words = Sjcl.sjcl##.random##randomWords (n/4+1) in
   let hex_words = hex_fromBits words in
   string_of_hex hex_words n
@@ -251,4 +248,7 @@ module Z = struct
   let shift_left x n = lib##shiftLeft x n
   let shift_right x n = lib##shiftRight x n
   let logand x y = lib##_and x y
+
+  let hash_modulus = of_int 1073741789 (* previous_prime(2^30) *)
+  let hash_to_int x = to_int (erem x hash_modulus)
 end
