@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                BELENIOS                                *)
 (*                                                                        *)
-(*  Copyright © 2012-2020 Inria                                           *)
+(*  Copyright © 2012-2021 Inria                                           *)
 (*                                                                        *)
 (*  This program is free software: you can redistribute it and/or modify  *)
 (*  it under the terms of the GNU Affero General Public License as        *)
@@ -71,7 +71,6 @@ let pbkdf2_generic toBits ~iterations ~salt x =
   pbkdf2 ~prf:MAC.hmac_sha256 ~iterations ~size:1 ~salt x |>
   transform_string (Hexa.encode ())
 
-let pbkdf2_hex = pbkdf2_generic Cryptokit.(transform_string (Hexa.decode ()))
 let pbkdf2_utf8 = pbkdf2_generic (fun x -> x)
 
 let aes_hex ~key ~data =
@@ -196,7 +195,7 @@ let decrypt ~key ~iv ~ciphertext =
 type rng = Cryptokit.Random.rng
 
 let secure_rng =
-  if Belenios_version.debug && Sys.getenv_opt "BELENIOS_USE_URANDOM" <> None
+  if Version.debug && Sys.getenv_opt "BELENIOS_USE_URANDOM" <> None
   then Cryptokit.Random.device_rng "/dev/urandom"
   else Cryptokit.Random.secure_rng
 
@@ -209,6 +208,10 @@ module Z = struct
   let ( =% ) = equal
   let bit_length x = Stdlib.(String.length (to_bits x) * 8)
 
-  let powm = powm_sec (* Warning: no efforts have been made to be
-                         constant time in the rest of the code. *)
+  let powm x a m =
+    if Z.compare a Z.zero = 0 then Z.one else powm_sec x a m
+    (* Warning: no efforts have been made to be constant time in the
+       rest of the code. *)
+
+  let hash_to_int = Z.hash
 end
