@@ -1,13 +1,15 @@
 #!/usr/bin/python
 # coding: utf-8
+import time
 import unittest
 import random
 import re
+import warnings
 from urllib.parse import urlencode
 from util.selenium_tools import wait_for_element_exists, wait_for_elements_exist, wait_for_element_exists_and_contains_expected_text, wait_for_an_element_with_partial_link_text_exists, verify_element_label, printable_page_source
 from util.election_testing import random_email_addresses_generator, populate_credential_and_password_for_voters_from_sent_emails, populate_random_votes_for_voters, repopulate_vote_confirmations_for_voters_from_sent_emails, wait_a_bit, build_css_selector_to_find_buttons_in_page_content_by_value, find_button_in_page_content_by_value, initialize_browser, election_page_url_to_election_id, verify_election_consistency, create_election_data_snapshot, delete_election_data_snapshot, log_in_as_administrator, log_out, administrator_starts_creation_of_election, administrator_edits_election_questions, administrator_sets_election_voters, administrator_validates_creation_of_election
 from util.execution import console_log
-from util.page_objects import ElectionHomePage, NormalVoteStep1Page, NormalVoteStep2Page, NormalVoteStep3Page, VoterLoginPage, NormalVoteStep5Page, NormalVoteStep6Page, BallotBoxPage
+from util.page_objects import ElectionHomePage, NormalVoteStep1Page, NormalVoteStep2Page, NormalVoteStep3Page, VoterLoginPage, NormalVoteStep5Page, NormalVoteStep6Page, BallotBoxPage, ResponsiveBoothStep1Page, ResponsiveBoothStep2Page, ResponsiveBoothStep3Page
 import settings
 
 
@@ -42,6 +44,16 @@ class BeleniosElectionTestBase(unittest.TestCase):
         self.election_id = None
 
 
+    @classmethod
+    def setUpClass(cls):
+        """
+        Do not display in terminal output noisy warnings which seem related to Python, until we know what should be done for them not to appear.
+        Example of warning:
+        /usr/lib/python3.6/enum.py:859: ResourceWarning: unclosed <socket.socket fd=13, family=AddressFamily.AF_INET, type=SocketKind.SOCK_STREAM, proto=6, laddr=('127.0.0.1', 42418), raddr=('127.0.0.1', 49031)>
+        """
+        warnings.simplefilter("ignore", ResourceWarning)
+
+
     def update_voters_data(self, some_voters_data):
         """
         :param some_voters: a list of voter data
@@ -102,7 +114,8 @@ class BeleniosElectionTestBase(unittest.TestCase):
         generate_on_server_button_element = wait_for_element_exists(browser, generate_on_server_button_css_selector, settings.EXPLICIT_WAIT_TIMEOUT)
         generate_on_server_button_element.click()
 
-        wait_a_bit()
+        # Wait for emails to be delivered
+        time.sleep(10)
 
         # (Server sends emails to voters.) She checks that server does not show any error that would happen when trying to send these emails (this can happen if sendmail is not configured)
         confirmation_sentence_expected_text = "Credentials have been generated and mailed!"
@@ -188,7 +201,8 @@ pris en compte.
         generate_and_mail_missing_passwords_button_element = wait_for_element_exists(browser, build_css_selector_to_find_buttons_in_page_content_by_value(generate_and_mail_missing_passwords_button_label), settings.EXPLICIT_WAIT_TIMEOUT)
         generate_and_mail_missing_passwords_button_element.click()
 
-        wait_a_bit()
+        # Wait for emails to be delivered
+        time.sleep(10)
 
         # She checks that the page contains expected confirmation text, instead of an error (TODO: explain in which case an error can happen, and check that it does not show)
         confirmation_sentence_expected_text = "Passwords have been generated and mailed!"
@@ -294,7 +308,12 @@ pris en compte.
         timeout = settings.EXPLICIT_WAIT_TIMEOUT
 
         if direct:
-            browser.get(settings.SERVER_URL + "/vote.html#" + urlencode({"uuid": self.election_id}))
+            booth_url = None
+            if settings.BOOTH_VERSION == settings.BOOTH_VERSIONS.RESPONSIVE_BOOTH:
+                booth_url = settings.SERVER_URL + "/static/frontend/booth/vote.html#" + urlencode({"uuid": self.election_id, "lang": "en"})
+            else:
+                booth_url = settings.SERVER_URL + "/vote.html#" + urlencode({"uuid": self.election_id})
+            browser.get(booth_url)
 
         else:
             # Bob has received 2 emails containing an invitation to vote and all necessary credentials (election page URL, username, password). He goes to the election page URL.
@@ -311,61 +330,126 @@ pris en compte.
 
         wait_a_bit()
 
-        # A loading screen appears, then another screen appears. He clicks on the "Here" button. A modal opens (it is an HTML modal created using Window.prompt()), with an input field. He types his credential.
-        step_1_page = NormalVoteStep1Page(browser, timeout)
-        step_1_page.verify_page()
-        step_1_page.click_on_here_button_and_type_voter_credential(voter["credential"])
+        if settings.BOOTH_VERSION == settings.BOOTH_VERSIONS.RESPONSIVE_BOOTH:
+            # A loading screen appears, then another screen appears. It contains an input for credential and a "Next" button. He types his credential in the input field, and clicks on the "Next" button.
+            step_1_page = ResponsiveBoothStep1Page(browser, timeout)
+            step_1_page.verify_page()
+            step_1_page.type_voter_credential(voter["credential"])
+            step_1_page.click_next_button()
 
-        wait_a_bit()
+            wait_a_bit()
 
-        # A new screen appears, which has a title "Step 2/6: Answer to questions", and a content:
-        # "Question 1?"
-        # "Question #1 of 1 — select between 1 and 2 answer(s)"
-        # [ ] "Answer 1"
-        # [ ] "Answer 2"
-        # [Next]
-        # (where "[ ]" is a checkbox, and [Next] is a button)
-        step_2_page = NormalVoteStep2Page(browser, timeout)
-        step_2_page.verify_page()
+            # A new screen appears, which has a title "Answer to questions", and a content:
+            # "Question 1?"
+            # "Question #1 of 1 — select between 1 and 2 answer(s)"
+            # [ ] "Answer 1"
+            # [ ] "Answer 2"
+            # [Next]
+            # (where "[ ]" is a checkbox, and [Next] is a button)
+            step_2_page = ResponsiveBoothStep2Page(browser, timeout)
+            step_2_page.verify_page()
 
-        # He fills his votes to each answer of the question
-        vote_data = voter["votes"]
-        step_2_page.fill_vote_form(vote_data)
+            # He fills his votes to each answer of the question
+            vote_data = voter["votes"]
+            step_2_page.fill_vote_form(vote_data)
 
-        wait_a_bit()
+            wait_a_bit()
 
-        # He clicks on the "Next" button
-        step_2_page.click_on_next_button()
+            # He clicks on the "Next" button
+            step_2_page.click_next_button()
 
-        wait_a_bit()
+            wait_a_bit()
 
-        """
-        A new screen appears, showing:
+            """
+            A new screen appears, showing:
 
-        Step 3/6: Review and encrypt
-        Question 1?
-        - Answer 1
+            Review and encrypt
+            Your ballot is not yet in the ballot box, and has the following content:
+            Question 1?
+            - Answer 1
 
-        Your ballot has been encrypted, but has not been cast yet!
+            Your ballot has been encrypted, but has not been cast yet!
 
-        Your smart ballot tracker is sLRilXoAYcodIrjWrOqPrVXLNlRyCJAqFeeHZ4WCajU
+            Your smart ballot tracker is sLRilXoAYcodIrjWrOqPrVXLNlRyCJAqFeeHZ4WCajU
 
-        We invite you to save it in order to check later that it is taken into account.
+            We invite you to save it in order to check later that it is taken into account.
+            [Copy]
 
-        [Continue]
-        [Restart]
-        """
-        step_3_page = NormalVoteStep3Page(browser, timeout)
-        step_3_page.verify_page()
-        # He remembers the smart ballot tracker that is displayed.
-        smart_ballot_tracker_value = step_3_page.get_smart_ballot_tracker_value()
-        assert len(smart_ballot_tracker_value) > 5
-        voter["smart_ballot_tracker"] = smart_ballot_tracker_value
+            [Previous]
+            [Next]
+            """
 
-        # He clicks on the "Continue" button
-        step_3_page.click_on_continue_button()
+            step_3_page = ResponsiveBoothStep3Page(browser, timeout)
+            step_3_page.verify_page()
 
-        wait_a_bit()
+            # He remembers the smart ballot tracker that is displayed.
+            smart_ballot_tracker_value = step_3_page.get_smart_ballot_tracker_value()
+            step_3_page.verify_smart_ballot_tracker_value()
+            voter["smart_ballot_tracker"] = smart_ballot_tracker_value
+
+            # He clicks on the "Next" button
+            step_3_page.click_next_button()
+
+            wait_a_bit()
+
+            # import time
+            # time.sleep(1000)
+        else:
+            # A loading screen appears, then another screen appears. He clicks on the "Here" button. A modal opens (it is an HTML modal created using Window.prompt()), with an input field. He types his credential.
+            step_1_page = NormalVoteStep1Page(browser, timeout)
+            step_1_page.verify_page()
+            step_1_page.click_on_here_button_and_type_voter_credential(voter["credential"])
+
+            wait_a_bit()
+
+            # A new screen appears, which has a title "Step 2/6: Answer to questions", and a content:
+            # "Question 1?"
+            # "Question #1 of 1 — select between 1 and 2 answer(s)"
+            # [ ] "Answer 1"
+            # [ ] "Answer 2"
+            # [Next]
+            # (where "[ ]" is a checkbox, and [Next] is a button)
+            step_2_page = NormalVoteStep2Page(browser, timeout)
+            step_2_page.verify_page()
+
+            # He fills his votes to each answer of the question
+            vote_data = voter["votes"]
+            step_2_page.fill_vote_form(vote_data)
+
+            wait_a_bit()
+
+            # He clicks on the "Next" button
+            step_2_page.click_on_next_button()
+
+            wait_a_bit()
+
+            """
+            A new screen appears, showing:
+
+            Step 3/6: Review and encrypt
+            Question 1?
+            - Answer 1
+
+            Your ballot has been encrypted, but has not been cast yet!
+
+            Your smart ballot tracker is sLRilXoAYcodIrjWrOqPrVXLNlRyCJAqFeeHZ4WCajU
+
+            We invite you to save it in order to check later that it is taken into account.
+
+            [Continue]
+            [Restart]
+            """
+            step_3_page = NormalVoteStep3Page(browser, timeout)
+            step_3_page.verify_page()
+            # He remembers the smart ballot tracker that is displayed.
+            smart_ballot_tracker_value = step_3_page.get_smart_ballot_tracker_value()
+            assert len(smart_ballot_tracker_value) > 5
+            voter["smart_ballot_tracker"] = smart_ballot_tracker_value
+
+            # He clicks on the "Continue" button
+            step_3_page.click_on_continue_button()
+
+            wait_a_bit()
 
         # He arrives on the login page, with a login form (as he has not already logged in during this visit, he does not arrive directly on the step 5 page)
         login_page = VoterLoginPage(browser, timeout)
@@ -532,7 +616,7 @@ pris en compte.
 
 
     def some_voters_revote(self):
-        voters_list_we_pick_from = self.voters_email_addresses_who_have_voted.keys()
+        voters_list_we_pick_from = list(self.voters_email_addresses_who_have_voted.keys())
         voters_who_will_vote_now = random.sample(voters_list_we_pick_from, settings.NUMBER_OF_REVOTING_VOTERS)
         voters_who_will_vote_now_data = populate_credential_and_password_for_voters_from_sent_emails(self.fake_sent_emails_manager, voters_who_will_vote_now, settings.ELECTION_TITLE)
         voters_who_will_vote_now_data = populate_random_votes_for_voters(voters_who_will_vote_now_data)
@@ -541,7 +625,7 @@ pris en compte.
 
 
     def one_voter_revotes_after_the_election_is_closed(self):
-        voters_list_we_pick_from = self.voters_email_addresses_who_have_voted.keys()
+        voters_list_we_pick_from = list(self.voters_email_addresses_who_have_voted.keys())
         voters_who_will_vote_now = random.sample(voters_list_we_pick_from, 1)
         voters_who_will_vote_now_data = populate_credential_and_password_for_voters_from_sent_emails(self.fake_sent_emails_manager, voters_who_will_vote_now, settings.ELECTION_TITLE)
         voters_who_will_vote_now_data = populate_random_votes_for_voters(voters_who_will_vote_now_data)
